@@ -1,6 +1,28 @@
+#
+#   xts: eXtensible time-series 
+#
+#   Copyright (C) 2008  Jeffrey A. Ryan jeff.a.ryan @ gmail.com
+#
+#   Contributions from Joshua M. Ulrich
+#
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
+#
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
 `plot.xts` <- function(x, y=NULL,
                        type='l', auto.grid=TRUE,
                        major.ticks='auto', minor.ticks=TRUE, 
+                       major.format=TRUE,
                        bar.col='grey', candle.col='white',
                        ann=TRUE, axes=TRUE, 
                        ...) {
@@ -9,7 +31,7 @@
   if(is.null(y))
     xycoords <- xy.coords(x)
   time.scale <- periodicity(x)$scale
-  ep <- axTicksByTime(x,major.ticks)
+  ep <- axTicksByTime(x,major.ticks, format=major.format)
 
   otype <- type
 
